@@ -52,8 +52,8 @@ import org.apache.amoro.shade.thrift.org.apache.thrift.TMultiplexedProcessor;
 import org.apache.amoro.shade.thrift.org.apache.thrift.TProcessor;
 import org.apache.amoro.shade.thrift.org.apache.thrift.protocol.TBinaryProtocol;
 import org.apache.amoro.shade.thrift.org.apache.thrift.protocol.TProtocolFactory;
+import org.apache.amoro.shade.thrift.org.apache.thrift.server.THsHaServer;
 import org.apache.amoro.shade.thrift.org.apache.thrift.server.TServer;
-import org.apache.amoro.shade.thrift.org.apache.thrift.server.TThreadedSelectorServer;
 import org.apache.amoro.shade.thrift.org.apache.thrift.transport.TNonblockingServerSocket;
 import org.apache.amoro.shade.thrift.org.apache.thrift.transport.TTransportException;
 import org.apache.amoro.shade.thrift.org.apache.thrift.transport.TTransportFactory;
@@ -102,6 +102,14 @@ public class AmoroServiceContainer {
   public static void main(String[] args) {
     try {
       AmoroServiceContainer service = new AmoroServiceContainer();
+      Runtime.getRuntime()
+          .addShutdownHook(
+              new Thread(
+                  () -> {
+                    LOG.info("AMS service is shutting down...");
+                    service.dispose();
+                    LOG.info("AMS service has been shut down");
+                  }));
       while (true) {
         try {
           service.waitLeaderShip();
@@ -165,24 +173,37 @@ public class AmoroServiceContainer {
   }
 
   public void dispose() {
-    if (tableManagementServer != null) {
+    if (tableManagementServer != null && tableManagementServer.isServing()) {
+      LOG.info("Stopping table management server...");
       tableManagementServer.stop();
     }
-    if (optimizingServiceServer != null) {
+    if (optimizingServiceServer != null && optimizingServiceServer.isServing()) {
+      LOG.info("Stopping optimizing server...");
       optimizingServiceServer.stop();
     }
     if (httpServer != null) {
-      httpServer.stop();
+      LOG.info("Stopping http server...");
+      try {
+        httpServer.close();
+      } catch (Exception e) {
+        LOG.error("Error stopping http server", e);
+      }
     }
     if (tableService != null) {
+      LOG.info("Stopping table service...");
       tableService.dispose();
       tableService = null;
     }
     if (terminalManager != null) {
+      LOG.info("Stopping terminal manager...");
       terminalManager.dispose();
       terminalManager = null;
     }
-    optimizingService = null;
+    if (optimizingService != null) {
+      LOG.info("Stopping optimizing service...");
+      optimizingService.dispose();
+      optimizingService = null;
+    }
 
     EventsManager.dispose();
     MetricManager.dispose();
@@ -342,15 +363,13 @@ public class AmoroServiceContainer {
     TTransportFactory transportFactory = new TFramedTransport.Factory();
     TMultiplexedProcessor multiplexedProcessor = new TMultiplexedProcessor();
     multiplexedProcessor.registerProcessor(processorName, processor);
-    TThreadedSelectorServer.Args args =
-        new TThreadedSelectorServer.Args(serverTransport)
+    THsHaServer.Args args =
+        new THsHaServer.Args(serverTransport)
             .processor(multiplexedProcessor)
             .transportFactory(transportFactory)
             .protocolFactory(protocolFactory)
             .inputProtocolFactory(inputProtoFactory)
-            .executorService(executorService)
-            .selectorThreads(selectorThreads)
-            .acceptQueueSizePerThread(queueSizePerSelector);
+            .executorService(executorService);
     LOG.info(
         "The number of selector threads for the {} thrift server is: {}",
         processorName,
@@ -359,7 +378,7 @@ public class AmoroServiceContainer {
         "The size of per-selector queue for the {} thrift server is: {}",
         processorName,
         queueSizePerSelector);
-    return new TThreadedSelectorServer(args);
+    return new THsHaServer(args);
   }
 
   private ThreadFactory getThriftThreadFactory(String processorName) {
