@@ -33,6 +33,7 @@ import org.apache.amoro.api.resource.Resource;
 import org.apache.amoro.api.resource.ResourceGroup;
 import org.apache.amoro.properties.CatalogMetaProperties;
 import org.apache.amoro.server.exception.ForbiddenException;
+import org.apache.amoro.server.exception.IllegalTaskStateException;
 import org.apache.amoro.server.exception.ObjectNotExistsException;
 import org.apache.amoro.server.exception.PluginRetryAuthException;
 import org.apache.amoro.server.exception.TaskNotFoundException;
@@ -69,7 +70,7 @@ import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.DelayQueue;
 import java.util.concurrent.Delayed;
-import java.util.concurrent.Executor;
+import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Predicate;
@@ -99,7 +100,7 @@ public class DefaultOptimizingService extends StatedPersistentBase
   private final OptimizerKeeper optimizerKeeper = new OptimizerKeeper();
   private final TableService tableService;
   private final RuntimeHandlerChain tableHandlerChain;
-  private final Executor planExecutor;
+  private final ExecutorService planExecutor;
 
   public DefaultOptimizingService(Configurations serviceConfig, DefaultTableService tableService) {
     this.optimizerTouchTimeout = serviceConfig.getLong(AmoroManagementConf.OPTIMIZER_HB_TIMEOUT);
@@ -148,8 +149,8 @@ public class DefaultOptimizingService extends StatedPersistentBase
         .forEach(groupName -> LOG.warn("Unloaded task runtime in group {}", groupName));
   }
 
-  private void registerOptimizer(OptimizerInstance optimizer, boolean needPersistency) {
-    if (needPersistency) {
+  private void registerOptimizer(OptimizerInstance optimizer, boolean needPersistent) {
+    if (needPersistent) {
       doAs(OptimizerMapper.class, mapper -> mapper.insertOptimizer(optimizer));
     }
 
@@ -164,7 +165,9 @@ public class DefaultOptimizingService extends StatedPersistentBase
     doAs(OptimizerMapper.class, mapper -> mapper.deleteOptimizer(token));
     OptimizingQueue optimizingQueue = optimizingQueueByToken.remove(token);
     OptimizerInstance optimizer = authOptimizers.remove(token);
-    optimizingQueue.removeOptimizer(optimizer);
+    if (optimizingQueue != null) {
+      optimizingQueue.removeOptimizer(optimizer);
+    }
   }
 
   @Override
@@ -385,6 +388,7 @@ public class DefaultOptimizingService extends StatedPersistentBase
     optimizingQueueByGroup.clear();
     optimizingQueueByToken.clear();
     authOptimizers.clear();
+    planExecutor.shutdown();
   }
 
   public boolean canDeleteResourceGroup(String name) {
@@ -565,7 +569,14 @@ public class DefaultOptimizingService extends StatedPersistentBase
           task.getTaskId(),
           task.getResourceDesc());
       // optimizing task of suspending optimizer would not be counted for retrying
-      queue.retryTask(task);
+      try {
+        queue.retryTask(task);
+      } catch (IllegalTaskStateException e) {
+        LOG.error(
+            "Retry task {} failed due to {}, will check it in next round",
+            task.getTaskId(),
+            e.getMessage());
+      }
     }
 
     private Predicate<TaskRuntime> buildSuspendingPredication(Set<String> activeTokens) {
