@@ -225,6 +225,9 @@ public class OptimizingQueue extends PersistentBase {
     CompletableFuture.supplyAsync(() -> planInternal(tableRuntime), planExecutor)
         .whenComplete(
             (process, throwable) -> {
+              if (throwable != null) {
+                LOG.error("Failed to plan table {}", tableRuntime.getTableIdentifier(), throwable);
+              }
               long currentTime = System.currentTimeMillis();
               scheduleLock.lock();
               try {
@@ -232,12 +235,20 @@ public class OptimizingQueue extends PersistentBase {
                 planningTables.remove(tableRuntime.getTableIdentifier());
                 if (process != null) {
                   tableQueue.offer(process);
+                  String skipIds =
+                      skipTables.stream()
+                          .map(ServerTableIdentifier::getId)
+                          .sorted()
+                          .map(item -> item + "")
+                          .collect(Collectors.joining(","));
                   LOG.info(
-                      "Completed planning on table {} with {} tasks with a total cost of {} ms, skipping tables {}",
+                      "Completed planning on table {} with {} tasks with a total cost of {} ms, skipping {} tables,"
+                          + " id list:{}",
                       tableRuntime.getTableIdentifier(),
                       process.getTaskMap().size(),
                       currentTime - startTime,
-                      skipTables);
+                      skipTables.size(),
+                      skipIds);
                 } else if (throwable == null) {
                   LOG.info(
                       "Skip planning table {} with a total cost of {} ms.",
@@ -466,8 +477,6 @@ public class OptimizingQueue extends PersistentBase {
             persistProcessCompleted(false);
           }
         }
-      } catch (Exception e) {
-        LOG.error("accept result error:", e);
       } finally {
         lock.unlock();
       }
